@@ -538,16 +538,14 @@ sdm2 <- function(A,
   toleranceRec <- matrix(1, maxIteration, 1)
 
   for (k.iteration in 1:maxIteration) {
-    time <- 1
-    for (t in 2:numberOfPeriods) {
-      time <- time + 1
+    for (time in 2:numberOfPeriods) {
       xtp1 <- xNext(xtp1)
 
-      p[, t] <- xtp1$p
-      S[, , t] <- xtp1$S
-      q[, t] <- xtp1$q
-      z[, t] <- xtp1$z
-    } # for (t in 2:numberOfPeriods)
+      p[, time] <- xtp1$p
+      S[, , time] <- xtp1$S
+      q[, time] <- xtp1$q
+      z[, time] <- xtp1$z
+    } # for (time in 2:numberOfPeriods)
     ##### the end of an iteration
 
     if (ts) {
